\name{labeling}
\alias{extended}
\alias{wilkinson}
\alias{heckbert}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Axis Labeling
}
\description{
Variety of functions for generating axis labelings.
}
\usage{
extended(dmin, dmax, m, Q = c(1, 5, 2, 2.5, 4, 3), only.loose = FALSE, w = c(0.2, 0.25, 0.5, 0.05))
wilkinson(dmin, dmax, m, Q = c(1, 5, 2, 2.5, 3, 4, 1.5, 7, 6, 8, 9), mincoverage = 0.8, mrange = max(floor(m/2), 2):ceiling(6 * m))
heckbert(dmin, dmax, m)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dmin}{Minimum of the data range
}
  \item{dmax}{Maximum of the data range
}
  \item{m}{Number of tick marks requested, the functions may return more or less
}
  \item{Q}{Preference ordered set of nice label spacings, elements >= 1 and < 10 (the default values are those recommended by the authors)
}
  \item{only.loose}{Whether or not to generate only "loose" labelings where the extreme labels are outside the data range
}
  \item{w}{The weights applied to the four optimization components (simplicity, coverage, density, and legibility)
}
  \item{mincoverage}{The minimum ratio between the the data range and the labeling range, controlling the whitespace around the labeling
}
  \item{mrange}{The range of \code{m}, number of tick marks, that should be considered in the optimization search}
}

\details{
\code{extended} is an enhanced version of Wilkinson's optimization-based axis labeling approach. It is described in detail in our paper. See the references.

Note that not every function takes every parameter.

These functions are not as robust as \code{\link{pretty}}. In particular, \code{dmin} and \code{dmax} should be correctly ordered and they should not be equal.

\code{m} is number of tick marks, not the number of intervals as in \code{\link{pretty}}.
}
\value{
Returns a vector of tick locations. These functions assume that the range of the plot will be extended to include all the labels.
}
\references{
Heckbert, P. S. (1990) Nice numbers for graph labels, Graphics Gems I, Academic Press Professional, Inc.
Wilkinson, L. (2005) The Grammar of Graphics, Springer-Verlag New York, Inc.
Talbot, J., Lin, S., Hanrahan, P. (2010) An Extension of Wilkinson's Algorithm for Positioning Tick Labels on Axes, InfoVis 2010.
}
\author{
Justin Talbot <jtalbot@stanford.edu>
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{pretty}}
}
\examples{
heckbert(8.1, 14.1, 4)	# 5 10 15
wilkinson(8.1, 14.1, 4)	# 8 9 10 11 12 13 14 15
extended(8.1, 14.1, 4)	# 8 10 12 14

# When plotting, extend the plot range to include the labeling
# Should probably have a helper function to make this easier
data(iris)
x <- iris$Sepal.Width
y <- iris$Sepal.Length
xl <- extended(min(x), max(x), 6)
yl <- extended(min(y), max(y), 6)
plot(x, y, xlim=c(min(x,xl),max(x,xl)), ylim=c(min(y,yl),max(y,yl)), axes=FALSE, title="Extended labeling")
axis(1, at=xl)
axis(2, at=yl)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ dplot }
